@@ -173,10 +173,10 @@ class LivyJobSubmitter(AbstractJobSubmitter):
         config = {
             'file': os.path.join(deployment_location, "job_loader.py"),
             'pyFiles': [ os.path.join(deployment_location, "app.zip") ],
-            'files': [ os.path.join(deployment_location, "lib.zip") ],
             'args': [
                 '--run-id', run_id,
                 '--run-dir', os.path.join(run_dir, run_id),
+                '--lib-zip', os.path.join(deployment_location, "lib.zip")
             ]
         }
         base_lib_dir = self.config.get('base_lib_dir')
@@ -187,17 +187,25 @@ class LivyJobSubmitter(AbstractJobSubmitter):
         config.pop("display_name", None)  # livy job submitter does not support display_name
 
         service_url = self.config['service_url']
-        username = self.config['username']
-        password = self.config['password']
+        username = self.config.get('username')
+        password = self.config.get('password')
 
         # print(json.dumps(config))
-        r = requests.post(
-            os.path.join(service_url, "batches"),
-            data=json.dumps(config),
-            headers=headers,
-            auth=HTTPBasicAuth(username, password),
-            verify=False
-        )
+        if username is None:
+            r = requests.post(
+                os.path.join(service_url, "batches"),
+                data=json.dumps(config),
+                headers=headers,
+                verify=False
+            )
+        else:
+            r = requests.post(
+                os.path.join(service_url, "batches"),
+                data=json.dumps(config),
+                headers=headers,
+                auth=HTTPBasicAuth(username, password),
+                verify=False
+            )
         if r.status_code not in [200, 201]:
             msg = "Failed to submit the job, status: {}, error message: \"{}\"".format(
                 r.status_code,
@@ -255,7 +263,11 @@ class LivyJobSubmitter(AbstractJobSubmitter):
             # we enter the cli mode upon first reached the running status
             if cli_mode and not cli_entered and job_state == 'running':
                 cli_entered = True
-                cli_handler = CLIHandler(client_channel, lambda : get_job_status()['state'] not in ('success', 'dead', 'killed'))
+                cli_handler = CLIHandler(
+                    client_channel,
+                    lambda : get_job_status()['state'] not in ('success', 'dead', 'killed'),
+                    handlers
+                )
                 cli_handler.loop()
 
 
